@@ -1,23 +1,9 @@
 /***********************************************************************
-* Copyright 2003-2004  Max Howell <max.howell@methylblue.com>
-* Copyright 2008-2009  Martin Sandsmark <martin.sandsmark@kde.org>
-* Copyright 2017  Harald Sitter <sitter@kde.org>
+* SPDX-FileCopyrightText: 2003-2004 Max Howell <max.howell@methylblue.com>
+* SPDX-FileCopyrightText: 2008-2009 Martin Sandsmark <martin.sandsmark@kde.org>
+* SPDX-FileCopyrightText: 2017 Harald Sitter <sitter@kde.org>
 *
-* This program is free software; you can redistribute it and/or
-* modify it under the terms of the GNU General Public License as
-* published by the Free Software Foundation; either version 2 of
-* the License or (at your option) version 3 or any later version
-* accepted by the membership of KDE e.V. (or its successor approved
-* by the membership of KDE e.V.), which shall act as a proxy
-* defined in Section 14 of version 3 of the license.
-*
-* This program is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-* GNU General Public License for more details.
-*
-* You should have received a copy of the GNU General Public License
-* along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
 ***********************************************************************/
 
 #include "mainWindow.h"
@@ -151,7 +137,7 @@ void MainWindow::setupActions() //singleton function
     action = ac->addAction(QStringLiteral("scan_home"), this, &MainWindow::slotScanHomeFolder);
     action->setText(i18n("Scan &Home Folder"));
     action->setIcon(QIcon::fromTheme(QStringLiteral("user-home")));
-    ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL + Qt::Key_Home));
+    ac->setDefaultShortcut(action, QKeySequence(Qt::CTRL | Qt::Key_Home));
 
     action = ac->addAction(QStringLiteral("scan_root"), this, &MainWindow::slotScanRootFolder);
     action->setText(i18n("Scan &Root Folder"));
